@@ -74,10 +74,12 @@ public class Constants
 	public static string ChronojumpWebsite = "http://www.chronojump.org";
 	
 	//formulas
-	public static string DjIndexFormula = "Dj Index (tv-tc)/tc *100)";
-	public static string QIndexFormula = "Q index (tv/tc)";
+	public static string DjIndexFormula = "Dj Index: (tv-tc)/tc *100)";
+	public static string QIndexFormula = "Q index: (tv/tc)";
+	public static string DjPowerFormula = "Dj Power: mass*g*(fallHeight+1.226*(tv^2)) / (tc+tv)";
 	public static string DjIndexFormulaOnly = "(tv-tc)*100/(tc*1.0)"; //*1.0 for having double division
 	public static string QIndexFormulaOnly = "tv/(tc*1.0)"; //*1.0 for having double division
+	public static string DjPowerFormulaOnly = PersonSessionTable + ".weight * 9.81 * (fall/100.0 + 1.226 * (tv*tv) ) / ((tc+tv)*1.0)";
 	
 	public const string FvIndexFormula = "F/V sj+(100%)/sj *100";
 	public const string IeIndexFormula = "IE (cmj-sj)/sj *100";
@@ -570,6 +572,8 @@ public class Constants
 	
 	public static string DatabaseNotFound = Catalog.GetString("Error. Cannot find database.");
 	public static string DirectoryCannotOpen = Catalog.GetString("Error. Cannot open directory.");
+	public static string FileNotFound = Catalog.GetString("Error. File not found.");
+	public static string FileCopyProblem = Catalog.GetString("Error. Cannot copy file.");
 
 	public static string ChronopicDefaultPortWindows = "COM?";
 	public static string ChronopicDefaultPortLinux = "/dev/ttyUSB?";
@@ -744,6 +748,8 @@ public class Constants
 		
 	public enum Encoder1RMMethod { NONWEIGHTED, WEIGHTED, WEIGHTED2, WEIGHTED3 }
 	public enum ContextMenu { NONE, EDITDELETE, DELETE }
+	
+	public enum EncoderAutoSaveCurve { ALL, NONE, BESTMEANPOWER }
 
 	public enum DoubleContact {
 		FIRST, AVERAGE, LAST
@@ -782,7 +788,7 @@ public class Constants
 		"land",
 		"air",
 		"jump height",
-		"Curve",
+		"Repetition",
 		"Not enough data.",
 		"Encoder is not connected.", 
 		"prediction",
@@ -790,13 +796,12 @@ public class Constants
 		"Estimated percentual load =",
 		"Adapted from",
 		"Mean speed in concentric propulsive phase",
-		"Sorry, no curves matched your criteria.",
-		"Need 6 jumps and 4 phases for each jump",
-		"Need at least three jumps executed on the odd concentric phases",
+		"Sorry, no repetitions matched your criteria.",
+		"Need at least three jumps",
 		"Starting R",
 		"Loading libraries",
 		"Starting process",
-		"Curves processed",
+		"Repetitions processed",
 		"R tasks done"
 	};
 	/*
@@ -828,7 +833,7 @@ public class Constants
 		Catalog.GetString("land"),
 		Catalog.GetString("air"),
 		Catalog.GetString("jump height"),
-		Catalog.GetString("Curve"),
+		Catalog.GetString("Repetition"),
 		Catalog.GetString("Not enough data."),
 		Catalog.GetString("Encoder is not connected."),
 		Catalog.GetString("prediction"),
@@ -836,13 +841,12 @@ public class Constants
 		Catalog.GetString("Estimated percentual load ="),
 		Catalog.GetString("Adapted from"),
 		Catalog.GetString("Mean speed in concentric propulsive phase"),
-		Catalog.GetString("Sorry, no curves matched your criteria."),
-		Catalog.GetString("Need 6 jumps and 4 phases for each jump"),
-		Catalog.GetString("Need at least three jumps executed on the odd concentric phases"),
+		Catalog.GetString("Sorry, no repetitions matched your criteria."),
+		Catalog.GetString("Need at least three jumps"),
 		Catalog.GetString("Starting R"),
 		Catalog.GetString("Loading libraries"),
 		Catalog.GetString("Starting process"),
-		Catalog.GetString("Curves processed"),
+		Catalog.GetString("Repetitions processed"),
 		Catalog.GetString("R tasks done")
 	};
 }
