@@ -247,6 +247,7 @@ public class EncoderGraphROptions
 
 
 //used on TreeViews capture and analyze
+//in ec and ecS there are two separated curves, unfortunately, here is not known if it's ecc or con
 public class EncoderCurve
 {
 	public bool Record;	//only on capture
@@ -325,8 +326,39 @@ public class EncoderCurve
 			MeanPower + sep + PeakPower + sep + PeakPowerT + sep + 
 			PP_PPT;
 	}
+	
+	~EncoderCurve() {}
 }
 
+
+//to know which is the best curve in a signal...
+public class EncoderSignal
+{
+	private ArrayList curves;
+
+	public EncoderSignal (ArrayList curves) {
+		this.curves = curves;
+	}
+
+	//this can be an eccentric or concentric curve
+	public int FindPosOfBestMeanPower() {
+		double bestMeanPower = 0;
+		int bestMeanPowerPos = 0;
+		int i = 0;
+		foreach(EncoderCurve curve in curves) {
+			if(Convert.ToDouble(curve.MeanPower) > bestMeanPower) {
+				bestMeanPower = Convert.ToDouble(curve.MeanPower);
+				bestMeanPowerPos = i;
+			}
+			i++;
+		}
+		return bestMeanPowerPos;
+	}
+	
+	~EncoderSignal() {}
+}
+
+
 //related to encoderSignalCurve table
 public class EncoderSignalCurve {
 	public int uniqueID;
@@ -374,11 +406,6 @@ public class EncoderNeuromuscularData
 	public double cl_p_avg;
 	public double cl_p_max;
 
-	public int e2f_t;
-	public double e2f_f_max;
-	public int e2f_f_max_t;
-	public double e2f_rfd_max;
-
 	public EncoderNeuromuscularData () {
 	}
 
@@ -388,8 +415,7 @@ public class EncoderNeuromuscularData
 			int e1_range, int e1_t, double e1_fmax, double e1_rfd_avg, double e1_i,
 			int ca_range, int cl_t, double cl_rfd_avg, double cl_i, 
 			double cl_f_avg, double cl_vf, double cl_f_max, 
-			double cl_s_avg, double cl_s_max, double cl_p_avg, double cl_p_max, 
-			int e2f_t, double e2f_f_max, int e2f_f_max_t, double e2f_rfd_max
+			double cl_s_avg, double cl_s_max, double cl_p_avg, double cl_p_max
 			)
 	{
 		this.n = n;
@@ -409,10 +435,6 @@ public class EncoderNeuromuscularData
 		this.cl_s_max = cl_s_max;
 		this.cl_p_avg = cl_p_avg;
 		this.cl_p_max = cl_p_max;
-		this.e2f_t = e2f_t;
-		this.e2f_f_max = e2f_f_max;
-		this.e2f_f_max_t = e2f_f_max_t;
-		this.e2f_rfd_max = e2f_rfd_max;
 	}
 
 	//reading contents file from graph.R
@@ -439,10 +461,6 @@ public class EncoderNeuromuscularData
 		this.cl_s_max 	= Convert.ToDouble(cells[14]);
 		this.cl_p_avg 	= Convert.ToDouble(cells[15]);
 		this.cl_p_max 	= Convert.ToDouble(cells[16]);
-		this.e2f_t 	= Convert.ToInt32(cells[17]);
-		this.e2f_f_max 	= Convert.ToDouble(cells[18]);
-		this.e2f_f_max_t = Convert.ToInt32(cells[19]);
-		this.e2f_rfd_max = Convert.ToDouble(cells[20]);
 	}
 
 	public string ToCSV() {
@@ -455,9 +473,7 @@ public class EncoderNeuromuscularData
 			cl_rfd_avg.ToString() + sep + cl_i.ToString() + sep + 
 			cl_f_avg.ToString() + sep + cl_vf.ToString() + sep + cl_f_max.ToString() + sep + 
 			cl_s_avg.ToString() + sep + cl_s_max.ToString() + sep + 
-			cl_p_avg.ToString() + sep + cl_p_max.ToString() + sep + 
-			e2f_t.ToString() + sep + e2f_f_max.ToString() + sep + 
-			e2f_f_max_t.ToString() + sep + e2f_rfd_max;
+			cl_p_avg.ToString() + sep + cl_p_max.ToString();
 	}
 }
 
@@ -534,7 +550,10 @@ public class EncoderSQL
 		else
 			ecconLong = Catalog.GetString("Concentric-eccentric");
 	}
-	
+
+	//used on encoder table
+	public enum Eccons { ALL, ecS, ceS, c } 
+
 	public string GetDate(bool pretty) {
 		int pointPos = filename.LastIndexOf('.');
 		int dateLength = 19; //YYYY-MM-DD_hh-mm-ss
