@@ -229,6 +229,8 @@ public partial class ChronoJumpWindow
 
 			saveOrDeleteCurveFromCaptureTreeView(rowNum, curve, ! val);
 			
+			/* temporarily removed message
+			 *
 			string message = "";
 			if(! val)
 				message = Catalog.GetString("Saved");
@@ -238,6 +240,7 @@ public partial class ChronoJumpWindow
 				label_encoder_curve_action.Text = message + " " + (rowNum +1).ToString();
 			else
 				label_encoder_curve_action.Text = message + " " + (decimal.Truncate((rowNum +1) /2) +1).ToString();
+				*/
 
 
 			//on ec, ecS need to [un]select second row
@@ -258,35 +261,62 @@ public partial class ChronoJumpWindow
 		}
 	}
 
-	
 	//allNone: true (save all), false (unsave all)
-	void encoderCaptureSaveCurvesAllNone(bool allNone)
+	void encoderCaptureSaveCurvesAllNoneBest(Constants.EncoderAutoSaveCurve saveOption)
 	{
-		int i = 0; //on "c": i is every row; on other eccons: i is every two rows
+		int bestRow = 0;
+		if(saveOption == Constants.EncoderAutoSaveCurve.BESTMEANPOWER) {
+			//get the concentric curves
+			EncoderSignal encoderSignal = new EncoderSignal(treeviewEncoderCaptureCurvesGetCurves(AllEccCon.CON));
+			bestRow = encoderSignal.FindPosOfBestMeanPower();
+			
+			//convert from c to ec. eg.
+			//three concentric curves: c[0], c[1], c[2]
+			//coming from three ecc-con: e[0], c[1], e[2], c[3], e[4], c[5]
+			//if from first list, c[2] is the best, then on second list it will be the ec curve: e[4],c[5]
+			//always multiply *2
+			if(ecconLast != "c")
+				bestRow *= 2;
+		}
+
+
+		int i = 0; //on "c" and ! "c": i is every row
 		string sep = "";
 		string messageRows = "";
+		
 		TreeIter iter;
 		bool iterOk = encoderCaptureListStore.GetIterFirst(out iter);
+		if(! iterOk)
+			return;
+
+		bool changeTo;
 		while(iterOk) {
 			TreePath path = encoderCaptureListStore.GetPath(iter);
 			
 			EncoderCurve curve = (EncoderCurve) encoderCaptureListStore.GetValue (iter, 0);
-			if(curve.Record != allNone) { 
+			if(
+					(! curve.Record && saveOption == Constants.EncoderAutoSaveCurve.ALL) ||
+					(! curve.Record && saveOption == Constants.EncoderAutoSaveCurve.BESTMEANPOWER && i == bestRow) ||
+					(curve.Record && saveOption == Constants.EncoderAutoSaveCurve.BESTMEANPOWER && i != bestRow) ||
+					(curve.Record && saveOption == Constants.EncoderAutoSaveCurve.NONE) ) 
+			{ 
+				changeTo = ! curve.Record;
+				
 				//change value
-				((EncoderCurve) encoderCaptureListStore.GetValue (iter, 0)).Record = allNone;
+				((EncoderCurve) encoderCaptureListStore.GetValue (iter, 0)).Record = changeTo;
 
 				//this makes RenderRecord work on changed row without having to put mouse there
 				encoderCaptureListStore.EmitRowChanged(path,iter);
 
 				//on "ecS" don't pass the 2nd row, pass always the first
-				saveOrDeleteCurveFromCaptureTreeView(i, curve, allNone);
+				saveOrDeleteCurveFromCaptureTreeView(i, curve, changeTo);
 				
 				if(ecconLast != "c") {
 					path.Next();
 					encoderCaptureListStore.IterNext (ref iter);
 				
 					//change value
-					((EncoderCurve) encoderCaptureListStore.GetValue (iter, 0)).Record = allNone;
+					((EncoderCurve) encoderCaptureListStore.GetValue (iter, 0)).Record = changeTo;
 
 					//this makes RenderRecord work on changed row without having to put mouse there
 					encoderCaptureListStore.EmitRowChanged(path,iter);
@@ -294,7 +324,16 @@ public partial class ChronoJumpWindow
 					
 				messageRows += sep + (i+1).ToString();
 				sep = ", ";
+			} else {
+				//if we don't change rows
+				//but is ec
+				//the advance now one row (the 'e')
+				//and later it will advance the 'c'
+				if(ecconLast != "c") {
+					encoderCaptureListStore.IterNext (ref iter);
+				}
 			}
+
 			i ++;
 			if(ecconLast != "c")
 				i ++;
@@ -302,13 +341,16 @@ public partial class ChronoJumpWindow
 			iterOk = encoderCaptureListStore.IterNext (ref iter);
 		}
 		//combo_encoder_capture_show_save_curve_button();
-			
+		
+		/* temporarily removed message
+		 *
 		string message = "";
-		if(allNone)
-			message = Catalog.GetString("Saved");
-		else
+		if(saveOption == Constants.EncoderAutoSaveCurve.NONE)
 			message = Catalog.GetString("Removed");
+		else
+			message = Catalog.GetString("Saved");
 		label_encoder_curve_action.Text = message + " " + messageRows;
+		*/
 
 			
 		updateUserCurvesLabelsAndCombo();
@@ -385,7 +427,7 @@ public partial class ChronoJumpWindow
 
 
 	string [] treeviewEncoderAnalyzeHeaders = {
-		Catalog.GetString("Curve") + "\n",
+		Catalog.GetString("Repetition") + "\n",
 		Catalog.GetString("Series") + "\n",
 		Catalog.GetString("Exercise") + "\n",
 		Catalog.GetString("Extra weight") + "\n (Kg)",
@@ -419,7 +461,8 @@ public partial class ChronoJumpWindow
 		} else {						//user curves
 			curvesData = SqliteEncoder.Select(
 					false, -1, currentPerson.UniqueID, currentSession.UniqueID, 
-					"curve", true, true);
+					"curve", EncoderSQL.Eccons.ALL, 
+					true, true);
 		}
 
 		string line;
@@ -564,11 +607,7 @@ public partial class ChronoJumpWindow
 		"cl s avg" + "\n (m/s)",
 		"cl s max" + "\n (m/s)",
 		"cl p avg" + "\n (W)",
-		"cl p max" + "\n (W)",
-		"e2f t" + "\n (ms)",
-		"e2f f fmax" + "\n (N)",
-		"e2f f fmax t" + "\n (ms)",
-		"e2f rfd max" + "\n (N/s)"
+		"cl p max" + "\n (W)"
 	};
 
 	private int createTreeViewEncoderAnalyzeNeuromuscular(string contents) {
@@ -668,18 +707,6 @@ public partial class ChronoJumpWindow
 				case 16:
 					aColumn.SetCellDataFunc (aCell, new Gtk.TreeCellDataFunc (Render_cl_p_max));
 					break;
-				case 17:
-					aColumn.SetCellDataFunc (aCell, new Gtk.TreeCellDataFunc (Render_e2f_t));
-					break;
-				case 18:
-					aColumn.SetCellDataFunc (aCell, new Gtk.TreeCellDataFunc (Render_e2f_f_max));
-					break;
-				case 19:
-					aColumn.SetCellDataFunc (aCell, new Gtk.TreeCellDataFunc (Render_e2f_f_max_t));
-					break;
-				case 20:
-					aColumn.SetCellDataFunc (aCell, new Gtk.TreeCellDataFunc (Render_e2f_rfd_max));
-					break;
 			}
 			
 			treeview_encoder_analyze_curves.AppendColumn (aColumn);
@@ -1041,30 +1068,6 @@ public partial class ChronoJumpWindow
 		EncoderNeuromuscularData nm = (EncoderNeuromuscularData) model.GetValue (iter, 0);
 		(cell as Gtk.CellRendererText).Text = nm.cl_p_max.ToString();
 	}
-	
-	private void Render_e2f_t (Gtk.TreeViewColumn column, Gtk.CellRenderer cell, Gtk.TreeModel model, Gtk.TreeIter iter)
-	{
-		EncoderNeuromuscularData nm = (EncoderNeuromuscularData) model.GetValue (iter, 0);
-		(cell as Gtk.CellRendererText).Text = nm.e2f_t.ToString();
-	}
-
-	private void Render_e2f_f_max (Gtk.TreeViewColumn column, Gtk.CellRenderer cell, Gtk.TreeModel model, Gtk.TreeIter iter)
-	{
-		EncoderNeuromuscularData nm = (EncoderNeuromuscularData) model.GetValue (iter, 0);
-		(cell as Gtk.CellRendererText).Text = nm.e2f_f_max.ToString();
-	}
-
-	private void Render_e2f_f_max_t (Gtk.TreeViewColumn column, Gtk.CellRenderer cell, Gtk.TreeModel model, Gtk.TreeIter iter)
-	{
-		EncoderNeuromuscularData nm = (EncoderNeuromuscularData) model.GetValue (iter, 0);
-		(cell as Gtk.CellRendererText).Text = nm.e2f_f_max_t.ToString();
-	}
-
-	private void Render_e2f_rfd_max (Gtk.TreeViewColumn column, Gtk.CellRenderer cell, Gtk.TreeModel model, Gtk.TreeIter iter)
-	{
-		EncoderNeuromuscularData nm = (EncoderNeuromuscularData) model.GetValue (iter, 0);
-		(cell as Gtk.CellRendererText).Text = nm.e2f_rfd_max.ToString();
-	}
 
 
 	/* end of rendering neuromuscular cols */
@@ -1110,6 +1113,39 @@ public partial class ChronoJumpWindow
 		return curve;
 	}
 
+	private enum AllEccCon { ALL, ECC, CON }
+
+	private ArrayList treeviewEncoderCaptureCurvesGetCurves(AllEccCon option) 
+	{
+		TreeIter iter;
+		ArrayList curves = new ArrayList();
+			
+		bool iterOk = encoderCaptureListStore.GetIterFirst(out iter);
+		if(! iterOk)
+			return curves;
+
+		bool oddRow = true;
+		while(iterOk) {
+			if(ecconLast != "c" && option == AllEccCon.CON && oddRow) {
+				oddRow = ! oddRow;
+				iterOk = encoderCaptureListStore.IterNext (ref iter);
+				continue;
+			}
+			if(ecconLast != "c" && option == AllEccCon.ECC && ! oddRow) {
+				oddRow = ! oddRow;
+				iterOk = encoderCaptureListStore.IterNext (ref iter);
+				continue;
+			}
+				
+			EncoderCurve curve = (EncoderCurve) encoderCaptureListStore.GetValue (iter, 0);
+			curves.Add(curve);
+
+			oddRow = ! oddRow;
+			iterOk = encoderCaptureListStore.IterNext (ref iter);
+		}
+
+		return curves;
+	}
 	
 	// ---------helpful methods -----------
 	
