@@ -87,6 +87,14 @@ public class PreferencesWindow {
 	[Widget] Gtk.RadioButton radio_graphs_translate;
 	[Widget] Gtk.RadioButton radio_graphs_no_translate;
 
+	[Widget] Gtk.RadioButton radio_use_heights_on_jump_indexes;
+	[Widget] Gtk.RadioButton radio_do_not_use_heights_on_jump_indexes;
+	
+	[Widget] Gtk.RadioButton radio_encoder_auto_save_curve_bestmeanpower;
+	[Widget] Gtk.RadioButton radio_encoder_auto_save_curve_all;
+	[Widget] Gtk.RadioButton radio_encoder_auto_save_curve_none;
+
+
 //	[Widget] Gtk.Box hbox_language_row;
 //	[Widget] Gtk.Box hbox_combo_language;
 //	[Widget] Gtk.ComboBox combo_language;
@@ -127,7 +135,9 @@ public class PreferencesWindow {
 			bool askDeletion, bool weightStatsPercent, bool heightPreferred, bool metersSecondsPreferred, 
 			string language, bool encoderPropulsive, double encoderSmoothCon,
 			string [] videoDevices, int videoDeviceNum, string encoder1RMMethod,
-			string CSVExportDecimalSeparator, bool RGraphsTranslate)
+			string CSVExportDecimalSeparator, bool RGraphsTranslate, bool useHeightsOnJumpIndexes,
+			Constants.EncoderAutoSaveCurve encoderAutoSaveCurve
+			)
 	{
 		if (PreferencesWindowBox == null) {
 			PreferencesWindowBox = new PreferencesWindow ();
@@ -249,6 +259,19 @@ public class PreferencesWindow {
 			PreferencesWindowBox.radio_graphs_translate.Active = true;
 		else
 			PreferencesWindowBox.radio_graphs_no_translate.Active = true;
+		
+		if(useHeightsOnJumpIndexes)
+			PreferencesWindowBox.radio_use_heights_on_jump_indexes.Active = true;
+		else
+			PreferencesWindowBox.radio_do_not_use_heights_on_jump_indexes.Active = true;
+			
+		if(encoderAutoSaveCurve == Constants.EncoderAutoSaveCurve.BESTMEANPOWER)
+			PreferencesWindowBox.radio_encoder_auto_save_curve_bestmeanpower.Active = true;
+		else if(encoderAutoSaveCurve == Constants.EncoderAutoSaveCurve.ALL)
+			PreferencesWindowBox.radio_encoder_auto_save_curve_all.Active = true;
+		else
+			PreferencesWindowBox.radio_encoder_auto_save_curve_none.Active = true;
+
 
 		PreferencesWindowBox.preferences.Show ();
 		return PreferencesWindowBox;
@@ -315,9 +338,18 @@ public class PreferencesWindow {
 		new DialogMessage(Constants.MessageTypes.INFO, 
 				Catalog.GetString("On jumps results tab, power is calculated depending on jump type:") + 
 				"\n\n" +
-				Catalog.GetString("Jumps with TC & TF: Bosco Relative Power (W/Kg)") + 
+				//Catalog.GetString("Jumps with TC & TF: Bosco Relative Power (W/Kg)") + 
+				//"\n" +
+				//Catalog.GetString("P = 24.6 * (Total time + Flight time) / Contact time") + 
+				Catalog.GetString("Jumps with TC & TF:") + " " + Catalog.GetString("Developed by Chronojump team") + 
 				"\n" +
-				Catalog.GetString("P = 24.6 * (Total time + Flight time) / Contact time") + 
+				Catalog.GetString("Calcule the potential energies on fall and after the jump.") + "\n" + 
+				Catalog.GetString("Divide them by time during force is applied.") +
+				"\n" +
+				//P = mass * g * ( fallHeight + 1.226 * Math.Pow(tf,2) ) / (Double)tt;
+				"P = " + Catalog.GetString("mass") + " * g * ( " + 
+				Catalog.GetString("falling height") + " + 1.226 * " + Catalog.GetString("flight time") + " ^ 2 ) / " + 
+				Catalog.GetString("total_time") +
 				"\n\n" +
 				Catalog.GetString("Jumps without TC: Lewis Peak Power 1974 (W)") + 
 				"\n" +
@@ -584,6 +616,16 @@ public class PreferencesWindow {
 		
 		SqlitePreferences.Update("RGraphsTranslate", 
 				PreferencesWindowBox.radio_graphs_translate.Active.ToString(), true);
+		
+		SqlitePreferences.Update("useHeightsOnJumpIndexes", 
+				PreferencesWindowBox.radio_use_heights_on_jump_indexes.Active.ToString(), true);
+		
+		if(PreferencesWindowBox.radio_encoder_auto_save_curve_bestmeanpower.Active)
+			SqlitePreferences.Update("encoderAutoSaveCurve", Constants.EncoderAutoSaveCurve.BESTMEANPOWER.ToString(), true);
+		else if(PreferencesWindowBox.radio_encoder_auto_save_curve_all.Active)
+			SqlitePreferences.Update("encoderAutoSaveCurve", Constants.EncoderAutoSaveCurve.ALL.ToString(), true);
+		else
+			SqlitePreferences.Update("encoderAutoSaveCurve", Constants.EncoderAutoSaveCurve.NONE.ToString(), true);
 	
 		string encoder1RMMethod = "";	
 		if(PreferencesWindowBox.radio_encoder_1RM_nonweighted.Active)
