@@ -174,7 +174,8 @@ public partial class ChronoJumpWindow {
 	
 	private static string [] comboStatsSubTypeWithTCOptions = {
 		Constants.DjIndexFormula,
-		Constants.QIndexFormula
+		Constants.QIndexFormula,
+		Constants.DjPowerFormula
 	};
 	
 	private static string [] comboStatsSubTypeReactiveOptions = {
@@ -868,7 +869,9 @@ public partial class ChronoJumpWindow {
 				evolution_mark_consecutives,
 				graphROptions,
 				graph,
-				toReport  //always false in this class
+				toReport,  //always false in this class
+				RGraphsTranslate,
+				useHeightsOnJumpIndexes
 				);
 
 		//if we just made a graph, store is not made, 
