@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  Copyright (C) 2004-2009   Xavier de Blas <xaviblas@gmail.com> 
+ *  Copyright (C) 2004-2014   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -41,6 +41,8 @@ public class Report : ExportSession
 	public bool ShowIntervalRunsWithSubruns;
 	public bool ShowReactionTimes;
 	public bool ShowPulses;
+	private bool graphTranslate = true;
+	private bool useHeightsOnJumpIndexes = true;
 	
 	bool toReport = true;
 
@@ -365,6 +367,8 @@ public class Report : ExportSession
 					graphROptions,
 					false, 			//graph
 					toReport,
+					graphTranslate,
+					useHeightsOnJumpIndexes,
 					writer,
 					"",
 					statCount
@@ -394,6 +398,8 @@ public class Report : ExportSession
 					graphROptions,
 					true, 			//graph
 					toReport,
+					graphTranslate,
+					useHeightsOnJumpIndexes,
 					writer,
 					fileName,		//fileName for exporting there
 					statCount
@@ -428,6 +434,16 @@ public class Report : ExportSession
 	public string Progversion {
 		set { progversion = value; }
 	}
+
+	public bool GraphTranslate {
+		set { graphTranslate = value; }
+		get { return graphTranslate; }
+	}
+	
+	public bool UseHeightsOnJumpIndexes {
+		set { useHeightsOnJumpIndexes = value; }
+		get { return useHeightsOnJumpIndexes; }
+	}
 	
 	~Report() {}
 	   
