@@ -74,7 +74,7 @@ class Sqlite
 	 * Important, change this if there's any update to database
 	 * Important2: if database version get numbers higher than 1, check if the comparisons with currentVersion works ok
 	 */
-	static string lastChronojumpDatabaseVersion = "1.08";
+	static string lastChronojumpDatabaseVersion = "1.11";
 
 	public Sqlite() {
 	}
@@ -164,7 +164,7 @@ class Sqlite
 		try{
 			Log.WriteLine(string.Format("Trying database in ... " + connectionString));
 
-//			dbcon = new SqliteConnection();
+		//dbcon = new SqliteConnection();
 			*/
 		/*
 			dbcon.ConnectionString = connectionString;
@@ -174,7 +174,7 @@ class Sqlite
 			try {
 				Log.WriteLine(string.Format("Trying database in ... " + connectionStringTemp));
 
-//				dbcon = new SqliteConnection();
+		//dbcon = new SqliteConnection();
 				dbcon.ConnectionString = connectionStringTemp;
 				dbcmd = dbcon.CreateCommand();
 			} catch { 
@@ -241,20 +241,20 @@ class Sqlite
 		Log.WriteLine("creating file...");
 		Log.WriteLine(connectionString);
 		
-	//	if(!Directory.Exists(home)) {
-	//		Directory.CreateDirectory (home);
-	//	}
+		//	if(!Directory.Exists(home)) {
+		//		Directory.CreateDirectory (home);
+		//	}
 
-//		try {	
-			dbcon.Open();
-			/*
-		} catch {
-			dbcon.Close();
-			dbcon.ConnectionString = connectionStringTemp;
-			dbcmd = dbcon.CreateCommand();
-			dbcon.Open();
-		}
-		*/
+		//try {	
+		dbcon.Open();
+		/*
+		   } catch {
+		   dbcon.Close();
+		   dbcon.ConnectionString = connectionStringTemp;
+		   dbcmd = dbcon.CreateCommand();
+		   dbcon.Open();
+		   }
+		   */
 		dbcon.Close();
 	}
 	
@@ -478,6 +478,7 @@ class Sqlite
 			bool needToConvertPersonToSport = false;
 			bool jumpFallAsDouble = false;
 	 		bool runAndRunIntervalInitialSpeedAdded = false;
+			bool addedRSA = false;
 
 			SqliteJumpRj sqliteJumpRjObject = new SqliteJumpRj();
 			SqliteRunInterval sqliteRunIntervalObject = new SqliteRunInterval();
@@ -1199,6 +1200,7 @@ class Sqlite
 				
 				//add know RSAs
 				SqliteRunIntervalType.addRSA();
+				addedRSA = true;
 
 				Log.WriteLine("Deleted fake RSA test and added known RSA tests.");
 				
@@ -1497,8 +1499,8 @@ class Sqlite
 		
 				SqliteEncoder.createTableEncoderSignalCurve();
 
-				ArrayList signals = SqliteEncoder.Select(true, -1, -1, -1, "signal", false, false);
-				ArrayList curves = SqliteEncoder.Select(true, -1, -1, -1, "curve", false, false);
+				ArrayList signals = SqliteEncoder.Select(true, -1, -1, -1, "signal", EncoderSQL.Eccons.ALL, false, false);
+				ArrayList curves = SqliteEncoder.Select(true, -1, -1, -1, "curve", EncoderSQL.Eccons.ALL, false, false);
 				int signalID;
 				conversionRateTotal = signals.Count;
 				conversionRate = 1;
@@ -1584,6 +1586,58 @@ class Sqlite
 
 				currentVersion = "1.08";
 			}
+			if(currentVersion == "1.08") {
+				dbcon.Open();
+			
+				Log.WriteLine("Added option on preferences to useHeightsOnJumpIndexes (default) or not");
+				
+				SqlitePreferences.Insert ("useHeightsOnJumpIndexes", "True"); 
+				SqlitePreferences.Update ("databaseVersion", "1.09", true); 
+				dbcon.Close();
+
+				currentVersion = "1.09";
+			}
+			if(currentVersion == "1.09") {
+				dbcon.Open();
+			
+				Log.WriteLine("Added RSA RAST on runType");
+
+				/*
+				 * addRSA() contains RAST since 1.10
+				 * database started at 1.10 or more contains RAST
+				 * database started before 0.87 adds RAST on the addRSA() method
+				 * satabase started after 0.87 adds RAST now
+				 */
+				if(! addedRSA) {
+					RunType type = new RunType();
+					type.Name = "RSA RAST 35, R10 x 6";
+					type.Distance = -1;
+					type.TracksLimited = true;
+					type.FixedValue = 12;
+					type.Unlimited = false;
+					type.Description = "RSA RAST Test";
+					type.DistancesString = "35-R10";
+					
+					SqliteRunIntervalType.Insert(type, Constants.RunIntervalTypeTable, true);
+					addedRSA = true;
+				}
+				
+				SqlitePreferences.Update ("databaseVersion", "1.10", true); 
+				dbcon.Close();
+
+				currentVersion = "1.10";
+			}
+			if(currentVersion == "1.10") {
+				dbcon.Open();
+			
+				Log.WriteLine("Added option on autosave curves on capture (all/bestmeanpower/none)");
+				
+				SqlitePreferences.Insert ("encoderAutoSaveCurve", Constants.EncoderAutoSaveCurve.BESTMEANPOWER.ToString()); 
+				SqlitePreferences.Update ("databaseVersion", "1.11", true); 
+				dbcon.Close();
+
+				currentVersion = "1.11";
+			}
 		
 		
 
@@ -1728,6 +1782,8 @@ class Sqlite
 		SqliteCountry.initialize();
 		
 		//changes [from - to - desc]
+		//1.09 - 1.10 Converted DB to 1.10 Added RSA RAST on runType
+		//1.08 - 1.09 Converted DB to 1.09 Added option on preferences to useHeightsOnJumpIndexes (default) or not
 		//1.07 - 1.08 Converted DB to 1.08 Added translate statistics graph option to preferences
 		//1.06 - 1.07 Converted DB to 1.07 Added jump_dj_a.png
 		//1.05 - 1.06 Converted DB to 1.06 Curves are now linked to signals
