@@ -79,6 +79,8 @@ class SqlitePreferences : Sqlite
 		Insert ("inertialmomentum", "0.01");
 		Insert ("CSVExportDecimalSeparator", Util.GetDecimalSeparatorFromLocale());
 		Insert ("RGraphsTranslate", "True");
+		Insert ("useHeightsOnJumpIndexes", "True");
+		Insert ("encoderAutoSaveCurve", Constants.EncoderAutoSaveCurve.BESTMEANPOWER.ToString()); 
 	}
 
 	public static void Insert(string myName, string myValue)
