@@ -254,7 +254,7 @@ class SqliteStat : Sqlite
 		}
 	}
 
-	//dj index, Q index, ... (indexType)
+	//dj index, Q index, Dj Power ( ... (indexType)
 	public static ArrayList DjIndexes (string indexType, string sessionString, bool multisession, string operationString, string jumpType, bool showSex)
 	{
 		string tp = Constants.PersonTable;
@@ -264,6 +264,8 @@ class SqliteStat : Sqlite
 			formula = Constants.DjIndexFormulaOnly;
 		} else if (indexType == "indexQ") {
 			formula = Constants.QIndexFormulaOnly;
+		} else if (indexType == "djPower") {
+			formula = Constants.DjPowerFormulaOnly;
 		}
 		string ini = "";
 		string end = "";
@@ -275,16 +277,28 @@ class SqliteStat : Sqlite
 			end = ")";
 		}
 		
+		//djPower needs personWeight on that session
+		string sep = "";
+		string tps = "";
+		string personSessionString = "";
+		string selectWeight = "";
+		if (indexType == "djPower") {
+			sep = ", ";
+			tps = Constants.PersonSessionTable;
+			personSessionString = " AND " + tp + ".uniqueID == " + tps + ".personID ";
+			selectWeight = ", " + tps + ".weight";
+		}
+		
 		string orderByString = "ORDER BY ";
 		string moreSelect = "";
-		moreSelect = ini + formula + end + " AS myIndex, jump.tv, jump.tc, jump.fall";
+		moreSelect = ini + formula + end + " AS myIndex, jump.tv, jump.tc, jump.fall" + selectWeight;
 		
 		//manage allJumps
-		string fromString = " FROM jump, " + tp + " ";
+		string fromString = " FROM jump, " + tp + sep + tps + " ";
 		string jumpTypeString = " AND jump.type == '" + jumpType + "' ";
 		if(jumpType == Constants.AllJumpsName) {
 			moreSelect = moreSelect + ", jump.type ";
-			fromString = " FROM jump, " + tp + ", jumpType ";
+			fromString = " FROM jump, " + tp + sep + tps + ", jumpType ";
 			jumpTypeString = " AND jumpType.startIn == 0 AND jump.Type == jumpType.name "; 
 		}
 
@@ -297,13 +311,14 @@ class SqliteStat : Sqlite
 		}
 		//if multisession, order by person.name, sessionID for being able to present results later
 		if(multisession) {
-			orderByString = orderByString + tp + ".name, sessionID, ";
+			orderByString = orderByString + tp + ".name, jump.sessionID, ";
 		}
 		
 		dbcon.Open();
-		dbcmd.CommandText = "SELECT " + tp + ".name, " + tp + ".sex, sessionID, " + moreSelect +
+		dbcmd.CommandText = "SELECT " + tp + ".name, " + tp + ".sex, jump.sessionID, " + moreSelect +
 			fromString +
 			sessionString +
+			personSessionString +
 			jumpTypeString +
 			" AND jump.personID == " + tp + ".uniqueID " +
 			groupByString +
@@ -322,6 +337,7 @@ class SqliteStat : Sqlite
 		string returnTvString = "";
 		string returnTcString = "";
 		string returnFallString = "";
+		string returnWeightString = "";
 		ArrayList myArray = new ArrayList(2);
 		while(reader.Read()) {
 			if(showSex) {
@@ -344,6 +360,11 @@ class SqliteStat : Sqlite
 				returnTvString = ":" + Util.ChangeDecimalSeparator(reader[4].ToString());
 				returnTcString = ":" + Util.ChangeDecimalSeparator(reader[5].ToString());
 				returnFallString = ":" + reader[6].ToString();
+				
+				returnWeightString = "";
+				if (indexType == "djPower")
+					returnWeightString = ":" + Util.ChangeDecimalSeparator(reader[7].ToString());
+
 			}
 
 			myArray.Add (reader[0].ToString() + showSexString + showJumpTypeString +
@@ -352,7 +373,8 @@ class SqliteStat : Sqlite
 					returnHeightString + 			//height
 					returnTvString + 			//tv
 					returnTcString + 			//tc
-					returnFallString			//fall
+					returnFallString +			//fall
+					returnWeightString
 				    );
 		}
 		reader.Close();
@@ -848,31 +870,29 @@ Log.WriteLine(intervalSpeeds);
 		return myArray;
 	}
 
-	public static ArrayList JumpIndexes (string sessionString, bool multisession, string ini, string end, string jump1, string jump2, bool showSex)
+	//1.4.7 useHeights is the new default, because this indexes should use height instead of TV that has been used by default since now
+	public static ArrayList JumpIndexes (string sessionString, bool multisession, string ini, string end, string jump1, string jump2, bool showSex, bool useHeights)
 	{
 		string tp = Constants.PersonTable;
 
-		//What's this? TODO: check old versions of this file
-		/*
-		string ini2 = "";
-		if(ini == "MAX(") {
-			ini2 = "MIN(";
-		} else if (ini == "AVG("){
-			ini2 = "AVG(";
-		}
-		*/
-			
 		string orderByString = "ORDER BY ";
 		string moreSelect = ""; 
+
+		string j1value = "j1.tv";
+		string j2value = "j2.tv";
+		if(useHeights) {
+			j1value = "j1.tv * j1.tv * 1.226";
+			j2value = "j2.tv * j2.tv * 1.226";
+		}
 		
 		//*1.0 for having double division
 		if(ini == "MAX(") {
 			//search MAX of two jumps, not max index!!
-			moreSelect = " ( MAX(j1.tv) - MAX(j2.tv) )*100/(MAX(j2.tv)*1.0) AS myIndex, " +
-				"MAX(j1.tv), MAX(j2.tv) ";
+			moreSelect = " ( MAX(" + j1value + ") - MAX(" + j2value + ") )*100/(MAX(" + j2value + ")*1.0) AS myIndex, " +
+				"MAX(" + j1value + "), MAX(" + j2value + ") ";
 		} else if(ini == "AVG(") {
-			moreSelect = " ( AVG(j1.tv) - AVG(j2.tv) )*100/(AVG(j2.tv)*1.0) AS myIndex, " +
-				"AVG(j1.tv), AVG(j2.tv)";
+			moreSelect = " ( AVG(" + j1value + ") - AVG(" + j2value + ") )*100/(AVG(" + j2value + ")*1.0) AS myIndex, " +
+				"AVG(" + j1value + "), AVG(" + j2value + ")";
 		}
 
 		//if we use AVG or MAX, then we have to group by the results
