@@ -41,13 +41,15 @@ public class StatTypeStruct
 	public GraphROptions GRO;
 	
 	public bool ToReport;
+	public bool GraphTranslate;
+	public bool UseHeightsOnJumpIndexes;
 	
 	public StatTypeStruct (string statisticApplyTo, 
 			ArrayList sendSelectedSessions, int prefsDigitsNumber, bool sex_active, 
 			int statsJumpsType, int limit, bool heightPreferred, bool weightStatsPercent, 
 			ArrayList markedRows, 
 			GraphROptions gRO,
-			bool toReport)
+			bool toReport, bool graphTranslate, bool useHeightsOnJumpIndexes)
 	{
 		this.StatisticApplyTo = statisticApplyTo;
 		this.SendSelectedSessions =  sendSelectedSessions;
@@ -60,6 +62,8 @@ public class StatTypeStruct
 		this.MarkedRows = markedRows;
 		this.GRO = gRO;
 		this.ToReport = toReport;
+		this.GraphTranslate = graphTranslate;
+		this.UseHeightsOnJumpIndexes = useHeightsOnJumpIndexes;
 	}
 }
 
@@ -76,6 +80,9 @@ public class StatType {
 
 	bool graph;
 	bool toReport;
+	bool graphTranslate;
+	bool useHeightsOnJumpIndexes;
+	
 	TextWriter writer;
 	string fileName;
 	int statCount; //optimal to create name of each graph on report: 1: 1.png; 2: 2.png
@@ -108,7 +115,7 @@ public class StatType {
 			ArrayList markedRows,  
 			int evolution_mark_consecutives, 
 			GraphROptions gRO,
-			bool graph, bool toReport)
+			bool graph, bool toReport, bool graphTranslate, bool useHeightsOnJumpIndexes)
 	{
 		//some of this will disappear when we use myStatTypeStruct in all classes:
 		this.statisticType = statisticType;
@@ -122,6 +129,8 @@ public class StatType {
 		
 		this.graph = graph;
 		this.toReport = toReport;
+		this.graphTranslate = graphTranslate;
+		this.useHeightsOnJumpIndexes = useHeightsOnJumpIndexes;
 
 		myStatTypeStruct = new StatTypeStruct (
 				statisticApplyTo,
@@ -129,7 +138,7 @@ public class StatType {
 				statsJumpsType, limit, heightPreferred, weightStatsPercent, 
 				markedRows, 
 				gRO,
-				toReport);
+				toReport, graphTranslate, useHeightsOnJumpIndexes);
 
 		myStat = new Stat(); //create an instance of myStat
 
@@ -163,7 +172,8 @@ public class StatType {
 			ArrayList markedRows, 
 			int evolution_mark_consecutives, 
 			GraphROptions gRO,
-			bool graph, bool toReport, TextWriter writer, string fileName,
+			bool graph, bool toReport, bool graphTranslate, bool useHeightsOnJumpIndexes, 
+			TextWriter writer, string fileName,
 			int statCount 
 			)
 	{
@@ -177,6 +187,9 @@ public class StatType {
 		
 		this.graph = graph;
 		this.toReport = toReport;
+		this.graphTranslate = graphTranslate;
+		this.useHeightsOnJumpIndexes = useHeightsOnJumpIndexes;
+
 		this.writer = writer;
 		this.fileName = fileName;
 		this.statCount = statCount;
@@ -187,7 +200,7 @@ public class StatType {
 				statsJumpsType, limit, heightPreferred, weightStatsPercent, 
 				markedRows, 
 				gRO,
-				toReport);
+				toReport, graphTranslate, useHeightsOnJumpIndexes);
 
 		myStat = new Stat(); //create and instance of myStat
 	}
@@ -330,6 +343,15 @@ public class StatType {
 				else 
 					myStat = new StatDjQ(myStatTypeStruct, treeview_stats);
 							//heightPreferred is not used, check this
+			
+			} else if(statisticSubType == Constants.DjPowerFormula)
+			{
+				if(graph) 
+					myStat = new GraphDjPower (myStatTypeStruct);
+							//heightPreferred is not used, check this
+				else 
+					myStat = new StatDjPower(myStatTypeStruct, treeview_stats);
+							//heightPreferred is not used, check this
 			}
 		}
 		else if(statisticType == Constants.TypeJumpsReactive) {
