@@ -77,6 +77,9 @@ public class Stat
 
 	protected bool toReport = false;
 	protected string reportString;
+	
+	protected bool graphTranslate = true;
+	protected bool useHeightsOnJumpIndexes;
 
 
 	//for toString() in every stat
@@ -119,6 +122,8 @@ public class Stat
 		
 		this.gRO = myStatTypeStruct.GRO;
 		this.toReport = myStatTypeStruct.ToReport;
+		this.graphTranslate = myStatTypeStruct.GraphTranslate;
+		this.useHeightsOnJumpIndexes = myStatTypeStruct.UseHeightsOnJumpIndexes;
 		
 		this.treeview = treeview;
 		
@@ -129,6 +134,13 @@ public class Stat
 
 		personsWithData = new ArrayList();
 	}
+
+	protected string translateYesNo(string str) {
+		if(graphTranslate)
+			return Catalog.GetString(str);
+		else
+			return str;
+	}
 	
 	void createCheckboxes(TreeView tv) 
 	{
