@@ -209,15 +209,13 @@ public class TreeViewJumps : TreeViewEvent
 			myData[count++] = Util.TrimDecimals(Util.GetHeightInCentimeters(newJump.Tv.ToString()), pDN);
 
 		
-		
-
 
 		if (showPower)  {
 			//takeoff has no tv. power should not be calculated
 			//calculate jumps with tf
 			if(newJump.Tv > 0) {	
 				if(newJump.Tc > 0) 	//if it's Dj (has tf, and tc)
-					myData[count++] = Util.TrimDecimals(Util.GetDjPower(newJump.Tc, newJump.Tv).ToString(), pDN);
+					myData[count++] = Util.TrimDecimals(Util.GetDjPower(newJump.Tc, newJump.Tv, personWeight, newJump.Fall).ToString(), pDN);
 				else {			//it's a normal jump without tc
 					//we calculate weightInKg again because can be changed in edit jump, and then treeview is no re-done
 					//but we do not calculate again person weight, because if it changes treeview is created again
@@ -244,6 +242,13 @@ public class TreeViewJumps : TreeViewEvent
 		myData[count++] = newJump.UniqueID.ToString();
 		return myData;
 	}
+	
+	//used on Add
+	public double PersonWeight {
+		set {
+			personWeight = value;
+		}
+	}
 
 }
 
